@@ -12,7 +12,7 @@ from cookiecutter.exceptions import OutputDirExistsException
 from .. import api
 from . import app, echo, theme
 
-__version__ = "0.0.11"
+__version__ = "0.0.12"
 
 cmd = typer.Typer()
 cmd.add_typer(app.cmd, name="app", help="Manage anvils apps and dependencies")
@@ -67,11 +67,14 @@ def stop():
 
 
 @cmd.command()
-def test():
+def test(
+    update: bool = typer.Option(False, help="Whether to update the docker image"),
+):
     """Run the test suite"""
     echo.progress("Checking for newer images")
     service = "test_runner"
-    api.build_image(service)
+    if update:
+        api.build_image(service)
     api.run_service(service)
 
 
